@@ -1,12 +1,12 @@
 module PuppetMetadata
   class AIO
     COMPATIBLE = {
-      'AlmaLinux'   => 'RedHat',
-      'Amazon'      => 'RedHat',
-      'CentOS'      => 'RedHat',
+      'AlmaLinux' => 'RedHat',
+      'Amazon' => 'RedHat',
+      'CentOS' => 'RedHat',
       'OracleLinux' => 'RedHat',
-      'Rocky'       => 'RedHat',
-      'Scientific'  => 'RedHat',
+      'Rocky' => 'RedHat',
+      'Scientific' => 'RedHat',
     }.freeze
 
     BUILDS = {
@@ -14,9 +14,9 @@ module PuppetMetadata
       'RedHat' => {
         '5' => 5..7,
         '6' => 5..7,
-        '7' => 5..7,
-        '8' => 5..7,
-        '9' => 6..7,
+        '7' => 5..8,
+        '8' => 5..8,
+        '9' => 6..8,
       },
       'Fedora' => {
         '26' => [5],
@@ -27,26 +27,27 @@ module PuppetMetadata
         '31' => 5..7,
         '32' => 6..7,
         '34' => 6..7,
+        '36' => 7..8,
       },
       'SLES' => {
         '11' => [7],
-        '12' => [7],
-        '15' => [7],
+        '12' => 7..8,
+        '15' => 7..8,
       },
       # deb-based
       'Debian' => {
         '7' => [5],
         '8' => 5..6,
         '9' => 5..7,
-        '10' => 5..7,
-        '11' => 6..7,
+        '10' => 5..8,
+        '11' => 6..8,
       },
       'Ubuntu' => {
         '14.04' => 5..6,
         '16.04' => 5..7,
-        '18.04' => 5..7,
-        '20.04' => 6..7,
-        '22.04' => 6..7,
+        '18.04' => 5..8,
+        '20.04' => 6..8,
+        '22.04' => 6..8,
       },
     }.freeze
 
@@ -55,6 +56,7 @@ module PuppetMetadata
       5 => '2.4',
       6 => '2.5',
       7 => '2.7',
+      8 => '3.2',
     }.freeze
 
     class << self
