@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'date'
 
 module PuppetMetadata
@@ -43,6 +45,12 @@ module PuppetMetadata
         '2.2' => '2003-06-30',
         '2.1' => '2000-09-30',
       },
+      # https://endoflife.date/oraclelinux
+      'OracleLinux' => {
+        '9' => '2032-06-30',
+        '8' => '2029-07-01',
+        '7' => '2024-07-01',
+      },
       # https://endoflife.software/operating-systems/linux/fedora
       'Fedora' => {
         '32' => nil,
@@ -115,7 +123,7 @@ module PuppetMetadata
         '19.10' => '2020-07-15',
         '19.04' => '2020-01-15',
         '18.10' => '2019-07-15',
-        '18.04' => '2023-04-15',
+        '18.04' => '2023-05-31',
         '17.10' => '2018-07-15',
         '17.04' => '2018-01-15',
         '16.10' => '2017-07-20',
@@ -157,8 +165,10 @@ module PuppetMetadata
       def eol_date(operatingsystem, release)
         releases = EOL_DATES[operatingsystem]
         return unless releases
+
         date = releases[release]
         return unless date
+
         Date.parse(date)
       end
 
@@ -193,8 +203,8 @@ module PuppetMetadata
       def supported_releases(operatingsystem)
         releases = EOL_DATES[operatingsystem]
         today = Date.today
-        releases.select { |release, eol_date| !eol_date || Date.parse(eol_date) > today }.keys.
-          sort_by { |release| Gem::Version.new(release) }
+        releases.select { |_release, eol_date| !eol_date || Date.parse(eol_date) > today }.keys
+                .sort_by { |release| Gem::Version.new(release) }
       end
     end
   end
